@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: adjunctions
 version: 4.3
-id: adjunctions-4.3-306c4088e5ded361b522da44159f8d3e
-key: adjun_J1Fl4UpiLfnKCPhCzHUp0g
+id: adjunctions-4.3-f44cc122c934a46b0d85d56e30c30dce
+key: adjun_3HXorLtQheMKAsbEilhAFA
 license: BSD3
 copyright: Copyright (C) 2011-2014 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -26,23 +26,23 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/adjunctions-4.3
-hs-libraries: HSadjunctions-4.3-J1Fl4UpiLfnKCPhCzHUp0g
+hs-libraries: HSadjunctions-4.3-3HXorLtQheMKAsbEilhAFA
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-eb230ef163a26fe6410daceeb92d736a
+    comonad-5-9b3bac8b2740903020c84a0c2eebf7b2
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    contravariant-1.4-1bd57c2540cd2864a467c8bf62a3fdb4
-    distributive-0.5.0.2-062a0a4262c71bd1a32922e0774f8a66
-    free-4.12.4-5e68614777ed20792496ad931a527625
+    contravariant-1.4-1b3716257293d15c38698a7852cba3ac
+    distributive-0.5.0.2-77d85d8c453ea57cf04087f9320d2bf7
+    free-4.12.4-8e24958a2bab136eded09b725d82baf6
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    profunctors-5.2-1a11bf84af8321e4318303d34ccac042
-    semigroupoids-5.0.1-9020d584fd071e35efe756eb398e9c78
-    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
-    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
+    profunctors-5.2-5f15e32dcb12ed9b3b3c97537d07181e
+    semigroupoids-5.0.1-8eb2d2c8f0f0def85cbb7c35538a003a
+    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
+    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
-    void-0.7.1-5298c6b3a32576797627b9b87532f9cb
+    void-0.7.1-255c5771d2d826ed3cb8a752061ff594
 haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
 haddock-html: /usr/share/doc/haskell-adjunctions/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
